aboutsummaryrefslogtreecommitdiff
path: root/include/_ctype.h
diff options
context:
space:
mode:
authorMike Barcroft <mike@FreeBSD.org>2002-08-21 16:20:02 +0000
committerMike Barcroft <mike@FreeBSD.org>2002-08-21 16:20:02 +0000
commitabbd8902334e8c6409384593b4a2c81f939b47b4 (patch)
tree7e9e16e835d265de592c113ee6c5d85f9be039cb /include/_ctype.h
parent9884a53c1a3e4753e347c793df6af4bd0298eab2 (diff)
downloadsrc-abbd8902334e8c6409384593b4a2c81f939b47b4.tar.gz
src-abbd8902334e8c6409384593b4a2c81f939b47b4.zip
Notes
Diffstat (limited to 'include/_ctype.h')
-rw-r--r--include/_ctype.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/include/_ctype.h b/include/_ctype.h
index 15a5b227dc34..e3d574d781ef 100644
--- a/include/_ctype.h
+++ b/include/_ctype.h
@@ -126,11 +126,11 @@ __END_DECLS
#define toascii(c) ((c) & 0x7F)
#endif
/* See comments in <machine/ansi.h> about _BSD_CT_RUNE_T_. */
__BEGIN_DECLS
-unsigned long ___runetype(_BSD_CT_RUNE_T_);
-_BSD_CT_RUNE_T_ ___tolower(_BSD_CT_RUNE_T_);
-_BSD_CT_RUNE_T_ ___toupper(_BSD_CT_RUNE_T_);
+unsigned long ___runetype(__ct_rune_t);
+__ct_rune_t ___tolower(__ct_rune_t);
+__ct_rune_t ___toupper(__ct_rune_t);
__END_DECLS
/*
@@ -149,34 +149,34 @@ __END_DECLS
#if !defined(_DONT_USE_CTYPE_INLINE_) && \
(defined(_USE_CTYPE_INLINE_) || defined(__GNUC__) || defined(__cplusplus))
static __inline int
-__maskrune(_BSD_CT_RUNE_T_ _c, unsigned long _f)
+__maskrune(__ct_rune_t _c, unsigned long _f)
{
return ((_c < 0 || _c >= _CACHED_RUNES) ? ___runetype(_c) :
_CurrentRuneLocale->runetype[_c]) & _f;
}
static __inline int
-__istype(_BSD_CT_RUNE_T_ _c, unsigned long _f)
+__istype(__ct_rune_t _c, unsigned long _f)
{
return (!!__maskrune(_c, _f));
}
static __inline int
-__isctype(_BSD_CT_RUNE_T_ _c, unsigned long _f)
+__isctype(__ct_rune_t _c, unsigned long _f)
{
return (_c < 0 || _c >= _CACHED_RUNES) ? 0 :
!!(_DefaultRuneLocale.runetype[_c] & _f);
}
-static __inline _BSD_CT_RUNE_T_
-__toupper(_BSD_CT_RUNE_T_ _c)
+static __inline __ct_rune_t
+__toupper(__ct_rune_t _c)
{
return (_c < 0 || _c >= _CACHED_RUNES) ? ___toupper(_c) :
_CurrentRuneLocale->mapupper[_c];
}
-static __inline _BSD_CT_RUNE_T_
-__tolower(_BSD_CT_RUNE_T_ _c)
+static __inline __ct_rune_t
+__tolower(__ct_rune_t _c)
{
return (_c < 0 || _c >= _CACHED_RUNES) ? ___tolower(_c) :
_CurrentRuneLocale->maplower[_c];
@@ -185,11 +185,11 @@ __tolower(_BSD_CT_RUNE_T_ _c)
#else /* not using inlines */
__BEGIN_DECLS
-int __maskrune(_BSD_CT_RUNE_T_, unsigned long);
-int __istype(_BSD_CT_RUNE_T_, unsigned long);
-int __isctype(_BSD_CT_RUNE_T_, unsigned long);
-_BSD_CT_RUNE_T_ __toupper(_BSD_CT_RUNE_T_);
-_BSD_CT_RUNE_T_ __tolower(_BSD_CT_RUNE_T_);
+int __maskrune(__ct_rune_t, unsigned long);
+int __istype(__ct_rune_t, unsigned long);
+int __isctype(__ct_rune_t, unsigned long);
+__ct_rune_t __toupper(__ct_rune_t);
+__ct_rune_t __tolower(__ct_rune_t);
__END_DECLS
#endif /* using inlines */
@@ -126,11 +126,11 @@ __END_DECLS
#define toascii(c) ((c) & 0x7F)
#endif
-/* See comments in <machine/ansi.h> about _BSD_CT_RUNE_T_. */
+/* See comments in <machine/_types.h> about __ct_rune_t. */
__BEGIN_DECLS